==> qtjambi-qml-debuginfo-macos-5.15.20.jar: sources/QtJambiQml/QQmlFileSelector_shell.h <==
#ifndef QQMLFILESELECTOR_SHELL_H
#define QQMLFILESELECTOR_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtQml/qqmlfileselector.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qfileselector.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtQml/qqmlengine.h>
#include <QtJambi/RegistryAPI>


class QQmlFileSelector_shell : public QQmlFileSelector, public QtJambiShellInterface
{
public:
    QQmlFileSelector_shell(QQmlEngine* engine0, QObject* parent1 = nullptr);
    ~QQmlFileSelector_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQmlFileSelector_access : public QQmlFileSelector
{
};

#endif // QQMLFILESELECTOR_SHELL_H

==> qtjambi-qml-debuginfo-macos-6.5.8.jar: sources/QtJambiQml/QQmlFileSelector_shell.h <==
#ifndef QQMLFILESELECTOR_SHELL_H
#define QQMLFILESELECTOR_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtQml/qqmlfileselector.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qfileselector.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtQml/qqmlengine.h>
#include <QtJambi/RegistryAPI>


class QQmlFileSelector_shell : public QQmlFileSelector, public QtJambiShellInterface
{
public:
    QQmlFileSelector_shell(QQmlEngine* engine0, QObject* parent1 = nullptr);
    ~QQmlFileSelector_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QQmlFileSelector_mshell;
    friend class QQmlFileSelector_oshell;
};


class QQmlFileSelector_mshell : public QQmlFileSelector_shell
{
public:
    using QQmlFileSelector_shell::QQmlFileSelector_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QQmlFileSelector_oshell : public QQmlFileSelector_mshell
{
public:
    using QQmlFileSelector_mshell::QQmlFileSelector_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQmlFileSelector_access : public QQmlFileSelector
{
};

#endif // QQMLFILESELECTOR_SHELL_H
